@@ -274,7 +274,7 @@ def load_images(shape=(250, 250)):
 
 
 
-class model(Aggregation2D):
+class fabba_model(Aggregation2D):
     """
     fABBA: A fast sorting-based aggregation method for symbolic time series representation
     
